# Generated by Django 5.0.3 on 2024-04-16 07:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("translator", "0023_azureaitranslator_summary_prompt_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="claudetranslator",
            name="model",
            field=models.CharField(
                default="claude-3-haiku-20240307",
                help_text="e.g. claude-3-haiku-20240307, claude-3-sonnet-20240229, claude-3-opus-20240229",
                max_length=50,
            ),
        ),
        migrations.AlterField(
            model_name="geminitranslator",
            name="model",
            field=models.CharField(
                default="gemini-pro",
                help_text="e.g. gemini-pro, gemini-1.5-pro",
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="moonshotaitranslator",
            name="model",
            field=models.CharField(
                default="moonshot-v1-8k",
                help_text="e.g. moonshot-v1-8k, moonshot-v1-32k, moonshot-v1-128k",
                max_length=100,
            ),
        ),
        migrations.AlterField(
            model_name="openaitranslator",
            name="model",
            field=models.CharField(
                default="gpt-3.5-turbo",
                help_text="e.g. gpt-3.5-turbo, gpt-4-turbo",
                max_length=100,
            ),
        ),
    ]
