# Generated by Django 5.0.1 on 2024-01-30 06:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('translator', '0005_caiyuntranslator_deeplxtranslator'),
    ]

    operations = [
        migrations.CreateModel(
            name='TestTranslator',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True, verbose_name='Name')),
                ('valid', models.BooleanField(null=True, verbose_name='Valid')),
                ('translated_text', models.TextField(default='@@Translated Text@@')),
                ('max_characters', models.IntegerField(default=50000)),
            ],
            options={
                'verbose_name': 'Test',
                'verbose_name_plural': 'Test',
            },
        ),
        migrations.AlterField(
            model_name='openaitranslator',
            name='prompt',
            field=models.TextField(
                default='Translate only the text from the following into {target_language},only returns translations.\n{text}'),
        ),
    ]
